@@ -242,8 +242,8 @@ dcPage::open(__('Blog settings'),
 if ($blog_id)
 {
 	echo '<h2>'.(!$standalone ? '<a href="blogs.php">'.__('Blogs').'</a> &rsaquo; ' : '').
-	html::escapeHTML($blog_name).' &rsaquo; '.
-	__('Blog settings').'</h2>';
+	html::escapeHTML($blog_name).' &rsaquo; <span class="page-title">'.
+	__('Blog settings').'</span></h2>';
 	
 	if (!empty($_GET['add'])) {
 		echo '<p class="message">'.__('Blog has been successfully created.').'</p>';
@@ -527,7 +527,7 @@ if ($blog_id)
 				if (!$v['super'] && $core->auth->isSuperAdmin()) {
 					echo
 					' - <a href="permissions.php?blog_id[]='.$blog_id.'&amp;user_id[]='.$k.'">'
-					.__('change permissions').'</a>';
+					.__('Change permissions').'</a>';
 				}
 				
 				echo '</h4>';
