@@ -165,24 +165,32 @@ $params['no_content'] = true;
 if ($user_id !== '' && in_array($user_id,$users_combo)) {
 	$params['user_id'] = $user_id;
 	$show_filters = true;
+} else {
+	$user_id='';
 }
 
 # - Categories filter
 if ($cat_id !== '' && in_array($cat_id,$categories_combo)) {
 	$params['cat_id'] = $cat_id;
 	$show_filters = true;
+} else {
+	$cat_id='';
 }
 
 # - Status filter
 if ($status !== '' && in_array($status,$status_combo)) {
 	$params['post_status'] = $status;
 	$show_filters = true;
+} else {
+	$status='';
 }
 
 # - Selected filter
 if ($selected !== '' && in_array($selected,$selected_combo)) {
 	$params['post_selected'] = $selected;
 	$show_filters = true;
+} else {
+	$selected='';
 }
 
 # - Month filter
@@ -190,23 +198,32 @@ if ($month !== '' && in_array($month,$dt_m_combo)) {
 	$params['post_month'] = substr($month,4,2);
 	$params['post_year'] = substr($month,0,4);
 	$show_filters = true;
+} else {
+	$month='';
 }
 
 # - Lang filter
 if ($lang !== '' && in_array($lang,$lang_combo)) {
 	$params['post_lang'] = $lang;
 	$show_filters = true;
+} else {
+	$lang='';
 }
 
 # - Sortby and order filter
 if ($sortby !== '' && in_array($sortby,$sortby_combo)) {
 	if ($order !== '' && in_array($order,$order_combo)) {
 		$params['order'] = $sortby.' '.$order;
+	} else {
+		$order='desc';
 	}
 	
 	if ($sortby != 'post_dt' || $order != 'desc') {
 		$show_filters = true;
 	}
+} else {
+	$sortby='post_dt';
+	$order='desc';
 }
 
 # Get posts
@@ -304,4 +321,4 @@ if (!$core->error->flag())
 
 dcPage::helpBlock('core_posts');
 dcPage::close();
-?>
\ No newline at end of file
+?>
