@@ -40,10 +40,12 @@ $user_ui_enhanceduploader = $core->auth->user_prefs->interface->enhanceduploader
 if ($core->auth->isSuperAdmin()) {
 	$user_ui_hide_std_favicon = $core->auth->user_prefs->interface->hide_std_favicon;
 }
+$user_ui_iconset = @$core->auth->user_prefs->interface->iconset;
 
 $default_tab = !empty($_GET['tab']) ? html::escapeHTML($_GET['tab']) : 'user-profile';
 
-if (!empty($_GET['append']) || !empty($_GET['removed']) || !empty($_GET['neworder']) || !empty($_GET['replaced'])) {
+if (!empty($_GET['append']) || !empty($_GET['removed']) || !empty($_GET['neworder']) || 
+	!empty($_GET['replaced']) || !empty($_POST['appendaction']) || !empty($_POST['removeaction'])) {
 	$default_tab = 'user-favorites';
 } elseif (!empty($_GET['updated'])) {
 	$default_tab = 'user-options';
@@ -60,6 +62,18 @@ foreach ($core->blog->getAllPostStatus() as $k => $v) {
 	$status_combo[$v] = $k;
 }
 
+$iconsets_combo = array(__('Default') => '');
+$iconsets_root = dirname(__FILE__).'/images/iconset/';
+if (is_dir($iconsets_root) && is_readable($iconsets_root)) {
+	if (($d = @dir($iconsets_root)) !== false) {
+		while (($entry = $d->read()) !== false) {
+			if ($entry != '.' && $entry != '..' && is_dir($iconsets_root.'/'.$entry)) {
+				$iconsets_combo[$entry] = $entry;
+			}
+		}
+	}
+}
+
 # Language codes
 $langs = l10n::getISOcodes(1,1);
 foreach ($langs as $k => $v) {
@@ -121,7 +135,8 @@ if (isset($_POST['user_name']))
 }
 
 # Update user options
-if (isset($_POST['user_post_format'])) {
+if (isset($_POST['user_post_format'])) 
+{
 	try
 	{
 		$cur = $core->con->openCursor($core->prefix.'user');
@@ -158,6 +173,7 @@ if (isset($_POST['user_post_format'])) {
 			# Applied to all users
 			$core->auth->user_prefs->interface->put('hide_std_favicon',!empty($_POST['user_ui_hide_std_favicon']),'boolean',null,true,true);
 		}
+		$core->auth->user_prefs->interface->put('iconset',(!empty($_POST['user_ui_iconset']) ? $_POST['user_ui_iconset'] : ''));
 		
 		# Udate user
 		$core->updUser($core->auth->userID(),$cur);
@@ -174,72 +190,90 @@ if (isset($_POST['user_post_format'])) {
 }
 
 # Add selected favorites
-if (!empty($_POST['appendaction']) && !empty($_POST['append'])) {
-	$ws = $core->auth->user_prefs->addWorkspace('favorites');
-	$user_favs = $ws->DumpLocalPrefs();
-	$count = count($user_favs);
-	foreach ($_POST['append'] as $k => $v)
-	{
-		try {
-			$found = false;
-			foreach ($user_favs as $f) {
-				$f = unserialize($f['value']);
-				if ($f['name'] == $v) {
-					$found = true;
-					break;
+if (!empty($_POST['appendaction'])) 
+{
+	try {
+		if (empty($_POST['append'])) {
+			throw new Exception(__('No favorite selected'));
+		}
+
+		$ws = $core->auth->user_prefs->addWorkspace('favorites');
+		$user_favs = $ws->DumpLocalPrefs();
+		$count = count($user_favs);
+		foreach ($_POST['append'] as $k => $v)
+		{
+			try {
+				$found = false;
+				foreach ($user_favs as $f) {
+					$f = unserialize($f['value']);
+					if ($f['name'] == $v) {
+						$found = true;
+						break;
+					}
 				}
+				if (!$found) {
+					$uid = sprintf("u%03s",$count);
+					$fav = array('name' => $_fav[$v][0],'title' => $_fav[$v][1],'url' => $_fav[$v][2],'small-icon' => $_fav[$v][3],
+						'large-icon' => $_fav[$v][4],'permissions' => $_fav[$v][5],'id' => $_fav[$v][6],'class' => $_fav[$v][7]);
+					$core->auth->user_prefs->favorites->put($uid,serialize($fav),'string');
+					$count++;
+				}
+			} catch (Exception $e) {
+				$core->error->add($e->getMessage());
+				break;
 			}
-			if (!$found) {
+		}
+	
+		if (!$core->error->flag()) {
+			http::redirect('preferences.php?append=1');
+		}
+	} catch (Exception $e) {
+		$core->error->add($e->getMessage());
+	}
+}
+
+# Delete selected favorites
+if (!empty($_POST['removeaction']))
+{
+	try {
+		if (empty($_POST['remove'])) {
+			throw new Exception(__('No favorite selected'));
+		}
+		
+		$ws = $core->auth->user_prefs->addWorkspace('favorites');
+		foreach ($_POST['remove'] as $k => $v)
+		{
+			try {
+				$core->auth->user_prefs->favorites->drop($v);
+			} catch (Exception $e) {
+				$core->error->add($e->getMessage());
+				break;
+			}
+		}
+		// Update pref_id values
+		try {
+			$user_favs = $ws->DumpLocalPrefs();
+			$core->auth->user_prefs->favorites->dropAll();
+			$count = 0;
+			foreach ($user_favs as $k => $v)
+			{
 				$uid = sprintf("u%03s",$count);
-				$fav = array('name' => $_fav[$v][0],'title' => $_fav[$v][1],'url' => $_fav[$v][2],'small-icon' => $_fav[$v][3],
-					'large-icon' => $_fav[$v][4],'permissions' => $_fav[$v][5],'id' => $_fav[$v][6],'class' => $_fav[$v][7]);
+				$f = unserialize($v['value']);
+				$fav = array('name' => $f['name'],'title' => $f['title'],'url' => $f['url'],'small-icon' => $f['small-icon'],
+					'large-icon' => $f['large-icon'],'permissions' => $f['permissions'],'id' => $f['id'],'class' => $f['class']);
 				$core->auth->user_prefs->favorites->put($uid,serialize($fav),'string');
 				$count++;
 			}
 		} catch (Exception $e) {
 			$core->error->add($e->getMessage());
-			break;
 		}
-	}
 	
-	if (!$core->error->flag()) {
-		http::redirect('preferences.php?append=1');
-	}
-}
-
-# Delete selected favorites
-if (!empty($_POST['removeaction']) && !empty($_POST['remove'])) {
-	$ws = $core->auth->user_prefs->addWorkspace('favorites');
-	foreach ($_POST['remove'] as $k => $v)
-	{
-		try {
-			$core->auth->user_prefs->favorites->drop($v);
-		} catch (Exception $e) {
-			$core->error->add($e->getMessage());
-			break;
-		}
-	}
-	// Update pref_id values
-	try {
-		$user_favs = $ws->DumpLocalPrefs();
-		$core->auth->user_prefs->favorites->dropAll();
-		$count = 0;
-		foreach ($user_favs as $k => $v)
-		{
-			$uid = sprintf("u%03s",$count);
-			$f = unserialize($v['value']);
-			$fav = array('name' => $f['name'],'title' => $f['title'],'url' => $f['url'],'small-icon' => $f['small-icon'],
-				'large-icon' => $f['large-icon'],'permissions' => $f['permissions'],'id' => $f['id'],'class' => $f['class']);
-			$core->auth->user_prefs->favorites->put($uid,serialize($fav),'string');
-			$count++;
+		if (!$core->error->flag()) {
+			http::redirect('preferences.php?removed=1');
 		}
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
-	
-	if (!$core->error->flag()) {
-		http::redirect('preferences.php?removed=1');
-	}
 }
 
 # Order favs
@@ -333,9 +367,7 @@ if (!empty($_GET['replaced'])) {
 		echo '<p class="message">'.__('Default favorites have been successfully updated.').'</p>';
 }
 
-echo '<h2>'.$page_title.'</h2>';
-
-$tabindex = 2;
+echo '<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <span class="page-title">'.$page_title.'</span></h2>';
 
 # User profile
 echo '<div class="multi-part" id="user-profile" title="'.__('My profile').'">';
@@ -346,29 +378,29 @@ echo
 '<div class="two-cols">'.
 '<div class="col">'.
 '<p><label for="user_name">'.__('Last Name:').
-form::field('user_name',20,255,html::escapeHTML($user_name),'',$tabindex++).'</label></p>'.
+form::field('user_name',20,255,html::escapeHTML($user_name)).'</label></p>'.
 
 '<p><label for="user_firstname">'.__('First Name:').
-form::field('user_firstname',20,255,html::escapeHTML($user_firstname),'',$tabindex++).'</label></p>'.
+form::field('user_firstname',20,255,html::escapeHTML($user_firstname)).'</label></p>'.
 
 '<p><label for="user_displayname">'.__('Display name:').
-form::field('user_displayname',20,255,html::escapeHTML($user_displayname),'',$tabindex++).'</label></p>'.
+form::field('user_displayname',20,255,html::escapeHTML($user_displayname)).'</label></p>'.
 
 '<p><label for="user_email">'.__('Email:').
-form::field('user_email',20,255,html::escapeHTML($user_email),'',$tabindex++).'</label></p>'.
+form::field('user_email',20,255,html::escapeHTML($user_email)).'</label></p>'.
 
 '<p><label for="user_url">'.__('URL:').
-form::field('user_url',30,255,html::escapeHTML($user_url),'',$tabindex++).'</label></p>'.
+form::field('user_url',30,255,html::escapeHTML($user_url)).'</label></p>'.
 
 '</div>'.
 
 '<div class="col">'.
 
 '<p><label for="user_lang">'.__('User language:').
-form::combo('user_lang',$lang_combo,$user_lang,'l10n',$tabindex++).'</label></p>'.
+form::combo('user_lang',$lang_combo,$user_lang,'l10n').'</label></p>'.
 
 '<p><label for="user_tz">'.__('User timezone:').
-form::combo('user_tz',dt::getZones(true,true),$user_tz,'',$tabindex++).'</label></p>'.
+form::combo('user_tz',dt::getZones(true,true),$user_tz).'</label></p>'.
 
 '</div>'.
 '</div>'.
@@ -382,23 +414,21 @@ if ($core->auth->allowPassChange())
 	'<legend>'.__('Change your password').'</legend>'.
 	
 	'<p><label for="new_pwd">'.__('New password:').
-	form::password('new_pwd',20,255,'','',$tabindex++).'</label></p>'.
+	form::password('new_pwd',20,255).'</label></p>'.
 	
 	'<p><label for="new_pwd_c">'.__('Confirm password:').
-	form::password('new_pwd_c',20,255,'','',$tabindex++).'</label></p>'.
+	form::password('new_pwd_c',20,255).'</label></p>'.
 	'</fieldset>'.
 	
-	'<fieldset>'.
-	'<p>'.__('If you want to change your email or password you must provide your current password.').'</p>'.
+	'<p>'.__('If you have changed this user email or password you must provide your current password to save these modifications.').'</p>'.
 	'<p><label for="cur_pwd">'.__('Your password:').
-	form::password('cur_pwd',20,255,'','',$tabindex++).'</label></p>'.
-	'</fieldset>';
+	form::password('cur_pwd',20,255).'</label></p>';
 }
 
 echo
 '<p class="clear">'.
 $core->formNonce().
-'<input type="submit" accesskey="s" value="'.__('Save').'" tabindex="33" /></p>'.
+'<input type="submit" accesskey="s" value="'.__('Save').'" /></p>'.
 '</form>';
 
 echo '</div>';
@@ -411,26 +441,34 @@ echo
 '<fieldset><legend>'.__('My options').'</legend>'.
 
 '<p><label for="user_post_format">'.__('Preferred format:').
-form::combo('user_post_format',$formaters_combo,$user_options['post_format'],'',$tabindex++).'</label></p>'.
+form::combo('user_post_format',$formaters_combo,$user_options['post_format']).'</label></p>'.
 
 '<p><label for="user_post_status">'.__('Default entry status:').
-form::combo('user_post_status',$status_combo,$user_post_status,'',$tabindex++).'</label></p>'.
+form::combo('user_post_status',$status_combo,$user_post_status).'</label></p>'.
 
 '<p><label for="user_edit_size">'.__('Entry edit field height:').
-form::field('user_edit_size',5,4,(integer) $user_options['edit_size'],'',$tabindex++).'</label></p>'.
+form::field('user_edit_size',5,4,(integer) $user_options['edit_size']).'</label></p>'.
 
 '<p><label for="user_wysiwyg" class="classic">'.
-form::checkbox('user_wysiwyg',1,$user_options['enable_wysiwyg'],'',$tabindex++).' '.
+form::checkbox('user_wysiwyg',1,$user_options['enable_wysiwyg']).' '.
 __('Enable WYSIWYG mode').'</label></p>'.
 
 '<p><label for="user_ui_enhanceduploader" class="classic">'.
-form::checkbox('user_ui_enhanceduploader',1,$user_ui_enhanceduploader,'',$tabindex++).' '.
+form::checkbox('user_ui_enhanceduploader',1,$user_ui_enhanceduploader).' '.
 __('Activate enhanced uploader in media manager').'</label></p>';
 
+if (count($iconsets_combo) > 1) {
+	echo 
+		'<p><label for="user_ui_iconset">'.__('Iconset:').
+		form::combo('user_ui_iconset',$iconsets_combo,$user_ui_iconset).'</label></p>';
+} else {
+	form::hidden('user_ui_iconset','');
+}
+
 if ($core->auth->isSuperAdmin()) {
 	echo
 	'<p><label for="user_ui_hide_std_favicon" class="classic">'.
-	form::checkbox('user_ui_hide_std_favicon',1,$user_ui_hide_std_favicon,'',$tabindex++).' '.
+	form::checkbox('user_ui_hide_std_favicon',1,$user_ui_hide_std_favicon).' '.
 	__('Do not use standard favicon').'</label></p>'.
 	'<p class="clear form-note info">'.__('This will be applied for all users').'</p>';
 }
@@ -443,7 +481,7 @@ echo
 '<fieldset><legend>'.__('Accessibility options').'</legend>'.
 
 '<p><label for="user_acc_nodragdrop" class="classic">'.
-form::checkbox('user_acc_nodragdrop',1,$user_acc_nodragdrop,'',$tabindex++).' '.
+form::checkbox('user_acc_nodragdrop',1,$user_acc_nodragdrop).' '.
 __('Disable javascript powered drag and drop for ordering items').'</label></p>'.
 
 '<p class="clear form-note info">'.__('Numeric fields will allow to type the elements\' ordering number.').'</p>'.
@@ -453,15 +491,15 @@ echo
 '<fieldset><legend>'.__('Dashboard modules').'</legend>'.
 
 '<p><label for="user_dm_doclinks" class="classic">'.
-form::checkbox('user_dm_doclinks',1,$user_dm_doclinks,'',$tabindex++).' '.
+form::checkbox('user_dm_doclinks',1,$user_dm_doclinks).' '.
 __('Display documentation links').'</label></p>'.
 
 '<p><label for="user_dm_dcnews" class="classic">'.
-form::checkbox('user_dm_dcnews',1,$user_dm_dcnews,'',$tabindex++).' '.
+form::checkbox('user_dm_dcnews',1,$user_dm_dcnews).' '.
 __('Display Dotclear news').'</label></p>'.
 
 '<p><label for="user_dm_quickentry" class="classic">'.
-form::checkbox('user_dm_quickentry',1,$user_dm_quickentry,'',$tabindex++).' '.
+form::checkbox('user_dm_quickentry',1,$user_dm_quickentry).' '.
 __('Display quick entry form').'</label></p>'.
 
 '<br class="clear" />'. //Opera sucks
@@ -473,7 +511,7 @@ $core->callBehavior('adminPreferencesForm',$core);
 echo
 '<p class="clear">'.
 $core->formNonce().
-'<input type="submit" accesskey="s" value="'.__('Save').'" tabindex="33" /></p>'.
+'<input type="submit" accesskey="s" value="'.__('Save').'" /></p>'.
 '</form>';
 
 echo '</div>';
@@ -495,7 +533,7 @@ foreach ($ws->dumpPrefs() as $k => $v) {
 			if ($count == 0) echo '<ul>';
 			$count++;
 			echo '<li id="fu-'.$k.'">'.
-				'<img src="'.$fav['large-icon'].'" alt="" /> '.
+				'<img src="'.dc_admin_icon_url($fav['large-icon']).'" alt="" /> '.
 				form::field(array('order['.$k.']'),2,3,$count,'position','',false,'title="'.sprintf(__('position of %s'),$fav['title']).'"').
 				form::hidden(array('dynorder[]','dynorder-'.$k.''),$k).
 				'<label for="fuk-'.$k.'">'.form::checkbox(array('remove[]','fuk-'.$k),$k).__($fav['title']).'</label>'.
@@ -541,7 +579,7 @@ foreach ($ws->dumpPrefs() as $k => $v) {
 			if ($count == 0) echo '<ul class="fav-list">';
 			$count++;
 			echo '<li id="fd-'.$k.'">'.
-			'<img src="'.$fav['small-icon'].'" alt="" /> '.__($fav['title']).'</li>';
+			'<img src="'.dc_admin_icon_url($fav['small-icon']).'" alt="" /> '.__($fav['title']).'</li>';
 		}
 	}
 }	
@@ -554,10 +592,10 @@ echo '<fieldset><legend>'.__('Available favorites').'</legend>';
 $count = 0;
 $array = $_fav;
 function cmp($a,$b) {
-    if ($a[1] == $b[1]) {
+    if (__($a[1]) == __($b[1])) {
         return 0;
     }
-    return ($a[1] < $b[1]) ? -1 : 1;
+    return (__($a[1]) < __($b[1])) ? -1 : 1;
 }
 $array=$array->getArrayCopy();
 uasort($array,'cmp');
@@ -567,7 +605,7 @@ foreach ($array as $k => $fav) {
 		$count++;
 		echo '<li id="fa-'.$fav[0].'">'.'<label for="fak-'.$fav[0].'">'.
 			form::checkbox(array('append[]','fak-'.$fav[0]),$k).
-			'<img src="'.$fav[3].'" alt="" /> '.'<span class="zoom"><img src="'.$fav[4].'" alt="" /></span>'.
+			'<img src="'.dc_admin_icon_url($fav[3]).'" alt="" /> '.'<span class="zoom"><img src="'.dc_admin_icon_url($fav[4]).'" alt="" /></span>'.
 			__($fav[1]).'</label>'.'</li>';
 	}
 }	
