@@ -187,8 +187,7 @@ class rsExtPost
 	*/
 	public static function getCategoryURL($rs)
 	{
-		return $rs->core->blog->url.$rs->core->url->getBase('category').'/'.
-		html::sanitizeURL($rs->cat_url);
+		return $rs->core->blog->url.$rs->core->url->getURLFor('category',html::sanitizeURL($rs->cat_url));
 	}
 	
 	/**
@@ -394,7 +393,7 @@ class rsExtPost
 	*/
 	public static function getTrackbackLink($rs)
 	{
-		return $rs->core->blog->url.$rs->core->url->getBase('trackback').'/'.$rs->post_id;
+		return $rs->core->blog->url.$rs->core->url->getURLFor('trackback',$rs->post_id);
 	}
 	
 	/**
@@ -777,7 +776,7 @@ class rsExtDates
 	{
 		$url = date('Y/m',strtotime($rs->dt));
 		
-		return $core->blog->url.$core->url->getBase('archive').'/'.$url;
+		return $core->blog->url.$core->url->getURLFor('archive',$url);
 	}
 	
 	/**
