@@ -16,7 +16,9 @@ $this->registerModule(
 	/* Description*/		"Generic antispam plugin for Dotclear",
 	/* Author */			"Alain Vagner",
 	/* Version */			'1.3.1',
-	/* Permissions */		'usage,contentadmin',
-	/* Priority */			10
+	array(
+		'permissions' =>	'usage,contentadmin',
+		'priority' =>		10
+	)
 );
 ?>
\ No newline at end of file
