@@ -390,11 +390,11 @@ if ($can_edit_page)
 	'accesskey="s" name="save" /> ';
 
 	if ($post_id) {
-		$preview_url =
-		$core->blog->url.$core->url->getBase('pagespreview').'/'.
+		$preview_url = $core->blog->url.
+		$core->url->getURLFor('pagespreview',
 		$core->auth->userID().'/'.
 		http::browserUID(DC_MASTER_KEY.$core->auth->userID().$core->auth->getInfo('user_pwd')).
-		'/'.$post->post_url;
+		'/'.$post->post_url);
 		echo '<a id="post-preview" href="'.$preview_url.'" class="button">'.__('Preview').'</a>';
 	}
 	
