@@ -16,6 +16,8 @@ $this->registerModule(
 	/* Description*/		"Ping services",
 	/* Author */			"Olivier Meunier",
 	/* Version */			'1.1',
-	/* Permissions */		'usage,contentadmin'
+	array(
+		'permissions' =>	'usage,contentadmin'
+	)
 );
 ?>
\ No newline at end of file
